#[repr(C)]pub struct CalculatorPowRequest {
pub base: Float64,
pub exponent: Float64,
}Expand description
The wire type corresponding to CalculatorPowRequest.
Fields
base: Float64exponent: Float64Trait Implementations
Sourceimpl Clone for CalculatorPowRequest
impl Clone for CalculatorPowRequest
Sourcefn clone(&self) -> CalculatorPowRequest
fn clone(&self) -> CalculatorPowRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for CalculatorPowRequest
impl Constrained for CalculatorPowRequest
Sourceimpl Debug for CalculatorPowRequest
impl Debug for CalculatorPowRequest
Sourceimpl<___D> Decode<___D> for CalculatorPowRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for CalculatorPowRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<CalculatorPowRequest, ___E> for &'a CalculatorPowRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<CalculatorPowRequest, ___E> for &'a CalculatorPowRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CalculatorPowRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CalculatorPowRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<CalculatorPowRequest, ___E> for CalculatorPowRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<CalculatorPowRequest, ___E> for CalculatorPowRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, CalculatorPowRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, CalculatorPowRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CalculatorPowRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CalculatorPowRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<CalculatorPowRequest, ___E> for CalculatorPowRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float64, ___E>,
T1: Encode<Float64, ___E>,
impl<___E, T0, T1> Encode<CalculatorPowRequest, ___E> for CalculatorPowRequest<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float64, ___E>,
T1: Encode<Float64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CalculatorPowRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CalculatorPowRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<CalculatorPowRequest> for CalculatorPowRequest
impl FromWire<CalculatorPowRequest> for CalculatorPowRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<CalculatorPowRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<CalculatorPowRequest, Self>
Sourcefn from_wire(wire: CalculatorPowRequest) -> Self
fn from_wire(wire: CalculatorPowRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<CalculatorPowRequest> for CalculatorPowRequest
impl FromWireRef<CalculatorPowRequest> for CalculatorPowRequest
Sourcefn from_wire_ref(wire: &CalculatorPowRequest) -> Self
fn from_wire_ref(wire: &CalculatorPowRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for CalculatorPowRequest
impl IntoNatural for CalculatorPowRequest
Sourcetype Natural = CalculatorPowRequest
type Natural = CalculatorPowRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for CalculatorPowRequest
impl Wire for CalculatorPowRequest
Sourcetype Narrowed<'de> = CalculatorPowRequest
type Narrowed<'de> = CalculatorPowRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.