#[repr(C)]pub struct CalculatorPowResponse {
pub power: Float64,
}Expand description
The wire type corresponding to CalculatorPowResponse.
Fields
power: Float64Trait Implementations
Sourceimpl Clone for CalculatorPowResponse
impl Clone for CalculatorPowResponse
Sourcefn clone(&self) -> CalculatorPowResponse
fn clone(&self) -> CalculatorPowResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for CalculatorPowResponse
impl Constrained for CalculatorPowResponse
Sourceimpl Debug for CalculatorPowResponse
impl Debug for CalculatorPowResponse
Sourceimpl<___D> Decode<___D> for CalculatorPowResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for CalculatorPowResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<CalculatorPowResponse, ___E> for &'a CalculatorPowResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<CalculatorPowResponse, ___E> for &'a CalculatorPowResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CalculatorPowResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CalculatorPowResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<CalculatorPowResponse, ___E> for CalculatorPowResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<CalculatorPowResponse, ___E> for CalculatorPowResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, CalculatorPowResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, CalculatorPowResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CalculatorPowResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CalculatorPowResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<CalculatorPowResponse, ___E> for CalculatorPowResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float64, ___E>,
impl<___E, T0> Encode<CalculatorPowResponse, ___E> for CalculatorPowResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<CalculatorPowResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<CalculatorPowResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<CalculatorPowResponse> for CalculatorPowResponse
impl FromWire<CalculatorPowResponse> for CalculatorPowResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<CalculatorPowResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<CalculatorPowResponse, Self>
Sourcefn from_wire(wire: CalculatorPowResponse) -> Self
fn from_wire(wire: CalculatorPowResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<CalculatorPowResponse> for CalculatorPowResponse
impl FromWireRef<CalculatorPowResponse> for CalculatorPowResponse
Sourcefn from_wire_ref(wire: &CalculatorPowResponse) -> Self
fn from_wire_ref(wire: &CalculatorPowResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for CalculatorPowResponse
impl IntoNatural for CalculatorPowResponse
Sourcetype Natural = CalculatorPowResponse
type Natural = CalculatorPowResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for CalculatorPowResponse
impl Wire for CalculatorPowResponse
Sourcetype Narrowed<'de> = CalculatorPowResponse
type Narrowed<'de> = CalculatorPowResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.